@@ -1,17 +1,16 @@
+#!/usr/bin/perl
+
 #
 # Uncomment the lines at the bottom accordingly
 # whether numeric or characteristic splitting shall be
 # committed.
 #
-# Source & target dir vars might require some adjustment.
-#
-
-
-use Dir::Split;
 
 use strict;
 use warnings;
 
+use Dir::Split;
+
 my ($return, %num_options, %char_options, $dir);
 
 $return = -255;
@@ -83,9 +82,7 @@ Target - dirs : $Dir::Split::track{'target'}{'dirs'}
 EOT
 }
 # no action
-elsif ($return == 0) {
-    print "None moved.\n";
-}
+elsif ($return == 0) { print "None moved.\n" }
 # existing files
 elsif ($return == -1) {
     print <<'EOT';
@@ -93,9 +90,11 @@ elsif ($return == -1) {
 START: DEBUG - EXISTS
 ---------------------
 EOT
+
     foreach (@Dir::Split::exists) {
         print "file:\t$_\n";
     }
+    
     print <<"EOT";
 -------------------
 END: DEBUG - EXISTS
@@ -111,31 +110,37 @@ EOT
 # copy or unlink failure
 elsif ($return == -2) {
     if (@Dir::Split::exists) {
+    
         print <<'EOT';
 ---------------------
 START: DEBUG - EXISTS
 ---------------------
 EOT
+
         foreach (@Dir::Split::exists) {
             print "file:\t$_\n";
         }
+	
         print <<'EOT';
 -------------------
 END: DEBUG - EXISTS
 -------------------
 EOT
     }
+    
     print <<'EOT';
 ----------------------
 START: DEBUG - FAILURE
 ----------------------
 EOT
+
     foreach (@{$Dir::Split::failure{'copy'}}) {
         print "copy failed:\t$_\n";
     }
     foreach (@{$Dir::Split::failure{'unlink'}}) {
         print "unlink failed:\t$_\n";
     }
+    
     print <<"EOT";
 --------------------
 END: DEBUG - FAILURE
