@@ -1,9 +1,9 @@
 #
-# $Id: Split.pm,v 0.51 2004/01/10 19:31:45 sts Exp $
+# $Id: Split.pm,v 0.52 2004/01/10 19:31:45 sts Exp $
 
 package Dir::Split;
 
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 
 use 5.6.1;
 use strict 'vars';
@@ -350,7 +350,7 @@ sub _gather_files {
         @Files = grep !-d File::Spec->catfile($o->{'source'}, $_), @Files;
     }
 
-    $track{'source'}{'files'} = scalar @Files;
+    $track{'source'}{'files'} = @Files;
 }
 
 #
@@ -384,7 +384,7 @@ sub _suffix {
     my $o = $_[0];
 
     if ($o->{'mode'} eq 'num') {
-        $o->_suffix_num_contin() if $o->{'num_contin'} == 1;
+        $o->_suffix_num_contin() if $o->{'num_contin'};
         $o->_suffix_num_sum_up();
     } else {
         $o->_suffix_char();
@@ -409,8 +409,8 @@ sub _suffix_num_contin {
     my $sep = quotemeta $o->{'sep'};
     foreach (@dirs) {
         # extract exist. identifier
-        ($_) = /(.+?)$sep(.*)/;
-        my $suff_cmp = $2;
+	my $suff_cmp;
+        ($_, $suff_cmp) = /(.+?)$sep(.*)/;
         # increase suffix to highest number
         if ($o->{'ident'} eq $_ && $suff_cmp =~ /[0-9]/o) {
             $Suffix = $suff_cmp if $suff_cmp > $Suffix;
@@ -611,6 +611,7 @@ sub _exists_and_not_override {
 
 sub _clean_up {
     undef @Dirs;
+    undef @Files;
     undef %F_names_case;
     undef %F_names_char;
     undef $Path;
